@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -101,8 +101,14 @@ from tempfile import mkdtemp
 
 import click
 
+
+EDM_CONFIG_LOCATION = os.path.abspath(os.path.join(
+    os.path.dirname(__file__),
+    'edm.yaml',
+))
+
 supported_combinations = {
-    '3.6': {'pyside2', 'pyside6', 'pyqt5', 'pyqt6', 'wx', 'null'},
+    '3.8': {'pyside2', 'pyside6', 'pyqt5', 'pyqt6', 'wx', 'null'},
 }
 
 # Default Python version to use in the comamnds below if none is specified.
@@ -111,11 +117,11 @@ DEFAULT_RUNTIME = '3.6'
 # Default toolkit to use if none specified.
 DEFAULT_TOOLKIT = 'null'
 
-# Required runtime dependencies. Should match install_requires in setup.py
+# Required runtime dependencies. Should match pyproject.toml.
 dependencies = {
-    # temporarily get pyface from pip until EDM release
-    # "pyface>=7.4.1",
+    "pyface>=8.0",
     "traits",
+    "setuptools",
 }
 
 # Dependencies we install from source for cron tests
@@ -126,7 +132,7 @@ source_dependencies = {
     "traits": "git+http://github.com/enthought/traits.git#egg=traits",
 }
 
-# The following should match extras_require in setup.py but with package
+# The following should match extras_require in pyproject.toml but with package
 # names compatible with EDM
 extra_dependencies = {
     'pyside2': {
@@ -136,7 +142,6 @@ extra_dependencies = {
         'pygments',
     },
     'pyqt5': {
-        'pyqt5',
         'pygments',
     },
     'pyqt6': {
@@ -154,13 +159,11 @@ extra_dependencies = {
         'h5py',
         'numpy',
         'pandas',
-        'pytables',
     },
     # Optional dependencies for some editors
     'editors': {
         'numpy',
         'pandas',
-        'pillow',
     },
     # Test dependencies also applied to installation from PYPI
     'test': {
@@ -168,6 +171,11 @@ extra_dependencies = {
     },
 }
 
+# Extra runtime dependencies
+runtime_dependencies = {
+    "3.8": {"pillow_simd", "tables"},
+}
+
 # Dependencies for CI jobs using this file.
 ci_dependencies = {
     "coverage",
@@ -183,20 +191,26 @@ doc_dependencies = {
 
 #: Paths to ignore in Sphinx-apidoc
 doc_ignore = {
-    "traitsui/qt4/*",
+    "traitsui/qt/*",
     "traitsui/wx/*",
     "*/tests",
 }
 
 environment_vars = {
-    'pyside2': {'ETS_TOOLKIT': 'qt', 'QT_API': 'pyside2'},
-    'pyside6': {'ETS_TOOLKIT': 'qt', 'QT_API': 'pyside6'},
-    'pyqt5': {"ETS_TOOLKIT": "qt", "QT_API": "pyqt5"},
-    'pyqt6': {"ETS_TOOLKIT": "qt", "QT_API": "pyqt6"},
+    'pyside2': {'ETS_TOOLKIT': 'qt4', 'QT_API': 'pyside2'},
+    'pyside6': {'ETS_TOOLKIT': 'qt4', 'QT_API': 'pyside6'},
+    'pyqt5': {"ETS_TOOLKIT": "qt4", "QT_API": "pyqt5"},
+    'pyqt6': {"ETS_TOOLKIT": "qt4", "QT_API": "pyqt6"},
     'wx': {'ETS_TOOLKIT': 'wx'},
     'null': {'ETS_TOOLKIT': 'null'},
 }
 
+# toolkit versions in EDM
+edm_versions = {
+    ('3.8', 'pyside6'),
+    ('3.8', 'pyqt6'),
+}
+
 # Location of documentation files
 HERE = os.path.dirname(__file__)
 DOCS_DIR = os.path.join(HERE, "docs")
@@ -243,48 +257,45 @@ def install(runtime, toolkit, environment, editable, source):
         | extra_dependencies["test"]
         | extra_dependencies["examples"]
         | extra_dependencies["editors"]
+        | runtime_dependencies[runtime]
         | ci_dependencies
     )
 
     # edm commands to setup the development environment
     commands = [
-        "edm environments create {environment} --force --version={runtime}"
+        "edm -c {config} environments create {environment} --force --version={runtime}",
+        "edm -c {config} install -y -e {environment} " + " ".join(packages),
     ]
 
-    commands.extend(
-        [
-            "edm install -y -e {environment} " + " ".join(packages),
-            "edm run -e {environment} -- pip install --force-reinstall -r ci-src-requirements.txt --no-dependencies",
-            "edm run -e {environment} -- python setup.py clean --all",
-        ]
-    )
-
-    # pip install pyqt5, pyqt6, pyside2 and pyside6, because we don't have them
-    # in EDM yet
-    if toolkit == 'pyside2':
-        commands.append("edm run -e {environment} -- pip install pyside2")
-    elif toolkit == 'pyqt6':
-        commands.append("edm run -e {environment} -- pip install pyqt6")
-    elif toolkit == 'pyside6':
-        if sys.platform == 'darwin':
-            commands.append("edm run -e {environment} -- pip install pyside6<6.2.2")
-        else:
-            commands.append("edm run -e {environment} -- pip install pyside6")
+    if (runtime, toolkit) in edm_versions:
+        commands.append(
+            "edm -c {config} install -y -e {environment} {toolkit}"
+        )
     elif toolkit == 'wx':
         if sys.platform != 'linux':
-            commands.append("edm run -e {environment} -- pip install wxPython")
+            commands.append("edm -c {config} run -e {environment} -- pip install wxPython")
         else:
             # XXX this is mainly for TravisCI workers; need a generic solution
             commands.append(
-                "edm run -e {environment} -- pip install -f https://extras.wxpython.org/wxPython4/extras/linux/gtk3/ubuntu-16.04/ wxPython"
+                "edm -c {config} run -e {environment} -- pip install -f https://extras.wxpython.org/wxPython4/extras/linux/gtk3/ubuntu-16.04/ wxPython"
             )
+    elif toolkit == 'pyside6':
+        commands.append('edm run -e {environment} -- pip install "pyside6"')
+    elif toolkit != "null":
+        commands.append("edm -c {config} run -e {environment} -- pip install {toolkit}")
+
+    commands.extend(
+        [
+            "edm -c {config} run -e {environment} -- pip install --force-reinstall -r ci-src-requirements.txt --no-dependencies",
+        ]
+    )
 
     click.echo("Creating environment '{environment}'".format(**parameters))
     execute(commands, parameters)
 
     if source:
         cmd_fmt = (
-            "edm plumbing remove-package --environment {environment} --force "
+            "edm -c {config} plumbing remove-package --environment {environment} --force "
         )
         commands = [
             cmd_fmt + dependency for dependency in source_dependencies.keys()
@@ -298,14 +309,14 @@ def install(runtime, toolkit, environment, editable, source):
             for pkg in source_pkgs
         ]
         commands = [
-            "edm run -e {environment} -- " + command for command in commands
+            "edm -c {config} run -e {environment} -- " + command for command in commands
         ]
         execute(commands, parameters)
 
     # Always install local source again with no dependencies
     # to mitigate risk of testing against a distributed release.
     install_traitsui = (
-        "edm run -e {environment} -- "
+        "edm -c {config} run -e {environment} -- "
         "pip install --force-reinstall  --no-dependencies "
     )
     if editable:
@@ -327,7 +338,7 @@ def shell(runtime, toolkit, environment):
     """
     parameters = get_parameters(runtime, toolkit, environment)
     commands = [
-        "edm shell -e {environment}",
+        "edm -c {config} shell -e {environment}",
     ]
     execute(commands, parameters)
 
@@ -344,11 +355,11 @@ def test(runtime, toolkit, environment):
 
     parameters["integrationtests"] = os.path.abspath("integrationtests")
     commands = [
-        "edm run -e {environment} -- python -X faulthandler -W default -m coverage run -p -m unittest discover -v traitsui",
+        "edm -c {config} run -e {environment} -- python -X faulthandler -W default -m coverage run -p -m unittest discover -v traitsui",
         # coverage run prevents local images to be loaded for demo examples
         # which are not defined in Python packages. Run with python directly
         # instead.
-        "edm run -e {environment} -- python -X faulthandler -W default -m unittest discover -v {integrationtests}",
+        "edm -c {config} run -e {environment} -- python -X faulthandler -W default -m unittest discover -v {integrationtests}",
     ]
 
     # We run in a tempdir to avoid accidentally picking up wrong traitsui
@@ -370,8 +381,7 @@ def cleanup(runtime, toolkit, environment):
     """Remove a development environment."""
     parameters = get_parameters(runtime, toolkit, environment)
     commands = [
-        "edm run -e {environment} -- python setup.py clean",
-        "edm environments remove {environment} --purge -y",
+        "edm -c {config} environments remove {environment} --purge -y",
     ]
     click.echo("Cleaning up environment '{environment}'".format(**parameters))
     execute(commands, parameters)
@@ -391,19 +401,6 @@ def test_clean(runtime, toolkit):
         cleanup(args=args, standalone_mode=False)
 
 
-@cli.command()
-@click.option('--runtime', default=DEFAULT_RUNTIME)
-@click.option('--toolkit', default=DEFAULT_TOOLKIT)
-@click.option('--environment', default=None)
-def update(runtime, toolkit, environment):
-    """Update/Reinstall package into environment."""
-    parameters = get_parameters(runtime, toolkit, environment)
-    commands = ["edm run -e {environment} -- python setup.py install"]
-    click.echo("Re-installing in  '{environment}'".format(**parameters))
-    execute(commands, parameters)
-    click.echo('Done update')
-
-
 @cli.command()
 @click.option('--runtime', default=DEFAULT_RUNTIME)
 @click.option('--toolkit', default=DEFAULT_TOOLKIT)
@@ -414,7 +411,7 @@ def docs(runtime, toolkit, environment):
     packages = ' '.join(doc_dependencies)
     ignore = " ".join(doc_ignore)
     commands = [
-        "edm install -y -e {environment} " + packages,
+        "edm -c {config} install -y -e {environment} " + packages,
     ]
     click.echo(
         "Installing documentation tools in  '{environment}'".format(
@@ -431,7 +428,7 @@ def docs(runtime, toolkit, environment):
     if not os.path.exists(output_path):
         os.makedirs(output_path)
     commands = [
-        "edm run -e {environment} -- sphinx-apidoc "
+        "edm -c {config} run -e {environment} -- sphinx-apidoc "
         "-e "
         "-M "
         "--no-toc "
@@ -442,7 +439,7 @@ def docs(runtime, toolkit, environment):
 
     os.chdir('docs')
     command = (
-        "edm run -e {environment} -- sphinx-build -b html "
+        "edm -c {config} run -e {environment} -- sphinx-build -b html "
         "-d build/doctrees "
         "source "
         "build/html"
@@ -493,7 +490,7 @@ def flake8(runtime, toolkit, environment, strict):
     if strict:
         config = "--config=flake8_strict.cfg "
     commands = [
-        "edm run -e {environment} -- python -m flake8 " + config,
+        "edm -c {config} run -e {environment} -- python -m flake8 " + config,
     ]
     execute(commands, parameters)
 
@@ -606,12 +603,13 @@ def build_changelog(ctx):
 # ----------------------------------------------------------------------------
 
 
-def get_parameters(runtime, toolkit, environment):
+def get_parameters(runtime, toolkit, environment, config=EDM_CONFIG_LOCATION):
     """Set up parameters dictionary for format() substitution"""
     parameters = {
         'runtime': runtime,
         'toolkit': toolkit,
         'environment': environment,
+        'config': config,
     }
     if toolkit not in supported_combinations[runtime]:
         msg = (
